BaseInfiniteListState<T> class abstract

Abstract base class for states in the InfiniteListBloc.

Implementers

Constructors

BaseInfiniteListState(InfiniteListState<T> state)
Constructs a BaseInfiniteListState.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state InfiniteListState<T>
The current InfiniteListState of type T.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited